==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Line/LineAngle/ts/LineAngle_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>LineAngle</name>
    <message>
        <location filename="../LineAngle.js" line="+65"/>
        <source>Position</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Wskaż położenie linii wymiarowej lub wprowadź kąt:
Wskaż położenie linii wymiarowej lub wprowadź kąt
Wskaż pozycje</translatorcomment>
        <translation type="unfinished">Położenie</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Specify position</source>
        <translatorcomment>--exact match--
--file: qcadactions_pl.ts--
Wskaż pozycje
Wskaż pozycję [kąt/długość]</translatorcomment>
        <translation type="unfinished">Wskaż pozycje</translation>
    </message>
    <message>
        <location filename="../LineAngle.ui" line="+17"/>
        <source>&amp;Angle:</source>
        <translatorcomment>--ignored colon--
--file: qcadguiqt_pl.ts--</translatorcomment>
        <translation type="unfinished">&amp;Kąt:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>&amp;Length:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Długość:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Reference Point:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Punkt odniesienia:</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Start</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wskaż kąt początkowy:
Wskaż kąt początkowy
Wskaż punkt początkowy lub [środek]</translatorcomment>
        <translation type="unfinished">Początek</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Middle</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
&amp;Punkt centralny
Środek
Przyciągaj do punktów pośrednich</translatorcomment>
        <translation type="unfinished">Środek</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>End</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Wskaż punkt końcowy odnośnika
Wskaż kąt końcowy lub [kąt/długość cięciwy]</translatorcomment>
        <translation type="unfinished">End</translation>
    </message>
    <message>
        <location filename="../LineAngleInit.js" line="+2"/>
        <source>Line from &amp;Angle</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Linia od kąta</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw line at a given absolute angle</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Narysować linię pod zadanym kątem absolutnym</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Line/LineAngle/ts/LineAngle_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>LineAngle</name>
    <message>
        <location filename="../LineAngle.js" line="+65"/>
        <source>Position</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Wskaż położenie linii wymiarowej lub wprowadź kąt:
Wskaż położenie linii wymiarowej lub wprowadź kąt
Wskaż pozycje</translatorcomment>
        <translation>Położenie</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Specify position</source>
        <translatorcomment>--exact match--
--file: qcadactions_pl.ts--
Wskaż pozycje
Wskaż pozycję [kąt/długość]</translatorcomment>
        <translation>Proszę określić położenie</translation>
    </message>
    <message>
        <location filename="../LineAngle.ui" line="+17"/>
        <source>&amp;Angle:</source>
        <translatorcomment>--ignored colon--
--file: qcadguiqt_pl.ts--</translatorcomment>
        <translation>&amp;Kąt:</translation>
    </message>
    <message>
        <location line="+26"/>
        <source>&amp;Length:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>&amp;Długość:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Reference Point:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Punkt &amp;odniesienia:</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Start</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wskaż kąt początkowy:
Wskaż kąt początkowy
Wskaż punkt początkowy lub [środek]</translatorcomment>
        <translation>Początek</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Middle</source>
        <translatorcomment>--exact match--
--file: qcadlib_pl.ts--
&amp;Punkt centralny
Środek
Przyciągaj do punktów pośrednich</translatorcomment>
        <translation>Środek</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>End</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Wskaż punkt końcowy odnośnika
Wskaż kąt końcowy lub [kąt/długość cięciwy]</translatorcomment>
        <translation>Koniec</translation>
    </message>
    <message>
        <location filename="../LineAngleInit.js" line="+2"/>
        <source>Line from &amp;Angle</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Linia pod &amp;kątem</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw line at a given absolute angle</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Rysuje linię pod zadanym kątem absolutnym</translation>
    </message>
</context>
</TS>
